@@ -115,7 +115,7 @@ class AlertCreator:
             if not all([isinstance(i[0], int) and isinstance(i[1], bool) for i in df]):
                 raise ValueError(ERROR_MSG_NOTLIST)
 
-    def _retrieve_previous_open_alerts(self, end_point):
+    def _retrieve_previous_open_alerts(self, end_point: int) -> List[Event]:
         previous_alerts_all = self.air_client.events.list_alerts(limit=-1)
         self._update_events_cache(previous_alerts_all)
         open_alerts = self.events_cache
@@ -127,8 +127,14 @@ class AlertCreator:
         return open_alerts
 
     def _write_events(
-        self, non_duplicated_new_events: List, end_point: int, notification_message: str
+        self,
+        non_duplicated_new_events: List,
+        end_point: int,
+        notification_message: str,
+        metadata: Optional[Dict] = None,
     ) -> Union[List, List[Event]]:
+        if metadata is None:
+            metadata = {}
         counter = 0
         written_events = []
         if len(non_duplicated_new_events) > 0:
@@ -137,6 +143,7 @@ class AlertCreator:
                     event,
                     end=end_point,
                     notification_message=notification_message,
+                    metadata=metadata,
                 )
                 # if event is not open and to short: ignore it
                 if ev.end_time is not None and ev.end_time - ev.start_time < self.minimum_length_of_alert:
@@ -158,12 +165,22 @@ class AlertCreator:
                     pass
         return written_events
 
+    def _get_existing_alerts(self, min_timestamp: int) -> Union[List[Event], List]:
+        return [
+            event
+            for event in self.events_cache
+            if event.start_time + self.merge_period >= min_timestamp
+            or (event.end_time is not None and event.end_time + self.merge_period >= min_timestamp)
+            or int(event.metadata.get(EVENT_END, 0)) + self.merge_period >= min_timestamp
+        ]
+
     def create_alerts(
         self,
         df: Union[pd.DataFrame, List[List]],
         end_point: int,
         notification_message: str,
         max_events_to_be_processed: int = -1,
+        metadata: Optional[Dict] = None,
     ) -> Tuple[List, List, int]:
         """Create non-overlapping alerts.
 
@@ -179,6 +196,8 @@ class AlertCreator:
                 visible in the Front End and sent by notification to the subscribed users.
             max_events_to_be_processed (int): When creating a lot of events it makes sense.
                 The end_point will be altered and returned.
+            metadata (Optional[Dict]): Additional metadata that will be written to the metadata of the alert
+
 
         Returns:
             List: Updated Events
@@ -186,6 +205,8 @@ class AlertCreator:
             int: Updated end when more events than max_events_to_be_processed. Use as new end.
 
         """
+        if metadata is None:
+            metadata = {}
         self._validate_df(df)
         if isinstance(df, pd.DataFrame):
             possible_events = self._create_deviation_events_from_pandas(df)
@@ -222,36 +243,51 @@ class AlertCreator:
             return [], [], end_point
 
         # remove duplicates
-        non_duplicated_new_events = _duplication_removal(new_events, open_alerts)
+        smallest_timestamp = new_events[0][0]
+        existing_alerts = self._get_existing_alerts(smallest_timestamp)
+        non_duplicated_new_events = _duplication_removal(new_events, existing_alerts)
+        non_duplicated_new_events = _duplication_removal(non_duplicated_new_events, open_alerts)
         non_duplicated_new_events = _duplication_removal(non_duplicated_new_events, events_to_be_updated)
 
         # if non duplicates exists create events
-        written_events = self._write_events(non_duplicated_new_events, end_point, notification_message)
+        written_events = self._write_events(non_duplicated_new_events, end_point, notification_message, metadata)
         if len(written_events) > 0:
             self._update_events_cache(written_events)
         print(f"Wrote {len(written_events)} Alerts")
         return events_to_be_updated, written_events, end_point
 
-    def _create_open_event(self, new_event: List[int], end: int, notification_message: str = "") -> Event:
+    def _validate_metadata(self, metadata: Dict = {}):
+        for key in metadata.keys():
+            if key in [MTD_SENDNOTIFICATION, MTD_SHOW, MTD_NOTIFICATION_MESSAGE]:
+                raise ValueError(f"Invalid metadata field: {key} is a reserved key for AIR.")
+
+    def _create_open_event(
+        self, new_event: List[int], end: int, notification_message: str = "", metadata: Optional[Dict] = None
+    ) -> Event:
         """`Create AIR ready events that can be parsed into AIREventsAPI.create_alerts`_
 
         Args:
             new_event (List[int]): A list of two integers denoting start and end time in ms.
             end (int): End time of the evaluation period in ms.
             notification_message (str): A message that is going to be sent to the subscriber.
+            metadata (Optional[Dict]): Additional metadata written to the alert
 
 
         """
+        if metadata is None:
+            metadata = {}
+        self._validate_metadata(metadata)
+
         start_time, end_time = new_event
         show = self._show_alert(start_time, end_time)
         notification = self._send_notification(start_time, end_time)
+        metadata[MTD_SENDNOTIFICATION] = str(notification)
+        metadata[MTD_SHOW] = str(show)
+        metadata[MTD_NOTIFICATION_MESSAGE] = notification_message
+
         event = Event(
             start_time=start_time,
-            metadata={
-                MTD_SENDNOTIFICATION: str(notification),
-                MTD_SHOW: str(show),
-                MTD_NOTIFICATION_MESSAGE: notification_message,
-            },
+            metadata=metadata,
         )
 
         event.metadata[EVENT_END] = str(end_time)
